Description Usage Arguments Value Examples
Run a food web.
1 2 3 4 5 6 7 8 9 10 11 |
tmax |
Duration over which to run the model. |
b |
Maximum value of the midge pulse. |
s |
Start time for midge pulse |
w |
Width of the midge pulse. |
tstep |
Step size in units of time. Defaults to |
pool_starts |
Named list of initial values for each pool. Names can include "N0", "D0", "P0", "V0", "H0", "R0", and "M0" (for nitrogen, detritus, plant, detritivore, herbivore, predator, and midge pools, respectively). Any pools not included here will start at their equilibrium value, except for midges that start at zero by default. |
ep_obj |
Output from the |
other_pars |
A named list of other parameter values to use instead of defaults.
Possible parameter names include all column names in |
midges_not_to |
Character specifying whether midges should NOT go to detritus
or NOT to predators. If |
A data frame with the following columns: time, pool, N.
1 2 3 | # What happens to the food web bc of this midge pulse?
web_output <- food_web(tmax = 1000, b = 400, s = 10, w = 40)
web_output
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.